@@ -6,7 +6,7 @@ Test::Strict - Check syntax, presence of use strict; and test coverage
 
 =head1 VERSION
 
-Version 0.39
+Version 0.40
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ use File::Find;
 use Config;
 
 our $COVER;
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 our $PERL    = $^X || 'perl';
 our $COVERAGE_THRESHOLD = 50; # 50%
 our $UNTAINT_PATTERN    = qr|^(.*)$|;
@@ -180,8 +180,8 @@ sub syntax_ok {
     my $is_script = _is_perl_script($file);
 
     # Set the environment to compile the script or module
-    my $inc = join(' -I ', map{ qq{"$_"} } @INC ) || '';
-    $inc = "-I $inc" if $inc;
+    require Config;
+    my $inc = join($Config::Config{path_sep}, @INC) || '';
     $file            = _untaint($file);
     my $perl_bin     = _untaint($PERL);
     local $ENV{PATH} = _untaint($ENV{PATH}) if $ENV{PATH};
@@ -191,7 +191,10 @@ sub syntax_ok {
     $switch = _taint_switch($file) || '' if $is_script;
 
     # Compile and check for errors
-    my $eval = `$perl_bin $inc -c$switch \"$file\" 2>&1`;
+    my $eval =  do {
+        local $ENV{PERL5LIB} = $inc;
+        `$perl_bin -c$switch \"$file\" 2>&1`;
+    };
     $file = quotemeta($file);
     my $ok = $eval =~ qr!$file syntax OK!ms;
     $Test->ok($ok, $test_txt);
